@echo off
:: bulkImportPST.bat - Bulk import PST files from a given directory into 
::                     the archive of a given user
::
:: Copyright (c) 2012 MailStore Software GmbH
:: 
:: Permission is hereby granted, free of charge, to any person obtaining
:: a copy of this software and associated documentation files (the
:: "Software"), to deal in the Software without restriction, including
:: without limitation the rights to use, copy, modify, merge, publish,
:: distribute, sublicense, and/or sell copies of the Software, and to
:: permit persons to whom the Software is furnished to do so, subject to
:: the following conditions:
:: 
:: The above copyright notice and this permission notice shall be
:: included in all copies or substantial portions of the Software.
:: 
:: THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
:: EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
:: MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
:: NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
:: LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
:: OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
:: WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

:: Configuration settings for MailStore Management Shell
:: Use double quotes for long file names and single quotes for text values
:: Output is suppressed, see logfiles for details
::set mailstoreCMD="C:\Program Files\deepinvent\MailStore Client MSI\MailStoreCmd.exe"
::set mailstoreCMD="C:\Program Files\deepinvent\MailStore Server\MailStoreCmd.exe"
set mailstoreCMD="C:\Program Files (x86)\deepinvent\MailStore Server\MailStoreCmd.exe"
set mailstoreHost='localhost'
set mailstoreFingerprint='be:ef:ca:fe:af:fe:fa:ce'
set mailstoreUser='admin'
set mailstorePassword='admin'
set mailstoreProfileName='templateBulkImportPST'
set mailstoreLogfile="C:\Documents and Settings\All Users\Application Data\MailStore\TaskLog\log_{DATE}-{TIME}_%2.log"

:: ################ DON'T CHANGE ANYTHING BELOW THIS LINE ################

:: Check if required command line arguments were given
if [%1]==[] goto usage
if [%2]==[] goto usage
if [%1]==[/?] goto usage
goto main

:: Print usage information 
:usage
echo Bulk import PST files from a given directory into the archive of a given user
echo. 
echo USAGE: %0 directory user
echo.
echo        directory      Specifies the directory where PST files are stored
echo        user           Specifies the user where the emails should be archived
echo.
exit /B 1

:: Main program
:main
set sourceDirectory=%1
set destinationUser=%2

setlocal EnableDelayedExpansion

:: Set codepage according to system language
:: 1252 works well for DE and EN
chcp 1252

:: Complete command line for callig MailStore Management Shell
set mailstoreCommandLine=%mailstoreCMD% --nologo --h=%mailstoreHost% --pkv3=%mailstoreFingerprint% --u=%mailstoreUser% --p=%mailstorePassword% --o=%mailstoreLogfile%

:: Loop through all PST files in given directory
for %%p in (%sourceDirectory%\*.pst) do (
  %mailstoreCommandLine% -c import-execute --name=%mailstoreProfileName% --[outlookProfile]="%%p" --[targetUserFolder]=%destinationUser%
)
